==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/search/kotlin/inputs/PrivateEndpointConnectionPropertiesPrivateLinkServiceConnectionStateArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.search.kotlin.inputs

import com.pulumi.azurenative.search.inputs.PrivateEndpointConnectionPropertiesPrivateLinkServiceConnectionStateArgs.builder
import com.pulumi.azurenative.search.kotlin.enums.PrivateLinkServiceConnectionStatus
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * Describes the current state of an existing Private Link Service connection to the Azure Private Endpoint.
 * @property actionsRequired A description of any extra actions that may be required.
 * @property description The description for the private link service connection state.
 * @property status Status of the the private link service connection. Can be Pending, Approved, Rejected, or Disconnected.
 */
public data class PrivateEndpointConnectionPropertiesPrivateLinkServiceConnectionStateArgs(
    public val actionsRequired: Output<String>? = null,
    public val description: Output<String>? = null,
    public val status: Output<PrivateLinkServiceConnectionStatus>? = null,
) :
    ConvertibleToJava<com.pulumi.azurenative.search.inputs.PrivateEndpointConnectionPropertiesPrivateLinkServiceConnectionStateArgs> {
    override fun toJava():
        com.pulumi.azurenative.search.inputs.PrivateEndpointConnectionPropertiesPrivateLinkServiceConnectionStateArgs =
        com.pulumi.azurenative.search.inputs.PrivateEndpointConnectionPropertiesPrivateLinkServiceConnectionStateArgs.builder()
            .actionsRequired(actionsRequired?.applyValue({ args0 -> args0 }))
            .description(description?.applyValue({ args0 -> args0 }))
            .status(status?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) })).build()
}

/**
 * Builder for [PrivateEndpointConnectionPropertiesPrivateLinkServiceConnectionStateArgs].
 */
@PulumiTagMarker
public class PrivateEndpointConnectionPropertiesPrivateLinkServiceConnectionStateArgsBuilder
internal constructor() {
    private var actionsRequired: Output<String>? = null

    private var description: Output<String>? = null

    private var status: Output<PrivateLinkServiceConnectionStatus>? = null

    /**
     * @param value A description of any extra actions that may be required.
     */
    @JvmName("htdyiloydehdmsie")
    public suspend fun actionsRequired(`value`: Output<String>) {
        this.actionsRequired = value
    }

    /**
     * @param value The description for the private link service connection state.
     */
    @JvmName("raqrkdqlcricktdl")
    public suspend fun description(`value`: Output<String>) {
        this.description = value
    }

    /**
     * @param value Status of the the private link service connection. Can be Pending, Approved, Rejected, or Disconnected.
     */
    @JvmName("utwsnkjerhnrmlbp")
    public suspend fun status(`value`: Output<PrivateLinkServiceConnectionStatus>) {
        this.status = value
    }

    /**
     * @param value A description of any extra actions that may be required.
     */
    @JvmName("iwuxspuoewghwxhy")
    public suspend fun actionsRequired(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.actionsRequired = mapped
    }

    /**
     * @param value The description for the private link service connection state.
     */
    @JvmName("lsmwfukuulxqmrqu")
    public suspend fun description(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.description = mapped
    }

    /**
     * @param value Status of the the private link service connection. Can be Pending, Approved, Rejected, or Disconnected.
     */
    @JvmName("albkdnnuomykespv")
    public suspend fun status(`value`: PrivateLinkServiceConnectionStatus?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.status = mapped
    }

    internal fun build(): PrivateEndpointConnectionPropertiesPrivateLinkServiceConnectionStateArgs =
        PrivateEndpointConnectionPropertiesPrivateLinkServiceConnectionStateArgs(
            actionsRequired = actionsRequired,
            description = description,
            status = status,
        )
}

==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/search/kotlin/inputs/PrivateEndpointConnectionPropertiesPrivateLinkServiceConnectionStateArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.search.kotlin.inputs

import com.pulumi.azurenative.search.inputs.PrivateEndpointConnectionPropertiesPrivateLinkServiceConnectionStateArgs.builder
import com.pulumi.azurenative.search.kotlin.enums.PrivateLinkServiceConnectionStatus
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * Describes the current state of an existing Private Link Service connection to the Azure Private Endpoint.
 * @property actionsRequired A description of any extra actions that may be required.
 * @property description The description for the private link service connection state.
 * @property status Status of the the private link service connection. Can be Pending, Approved, Rejected, or Disconnected.
 */
public data class PrivateEndpointConnectionPropertiesPrivateLinkServiceConnectionStateArgs(
    public val actionsRequired: Output<String>? = null,
    public val description: Output<String>? = null,
    public val status: Output<PrivateLinkServiceConnectionStatus>? = null,
) :
    ConvertibleToJava<com.pulumi.azurenative.search.inputs.PrivateEndpointConnectionPropertiesPrivateLinkServiceConnectionStateArgs> {
    override fun toJava():
        com.pulumi.azurenative.search.inputs.PrivateEndpointConnectionPropertiesPrivateLinkServiceConnectionStateArgs =
        com.pulumi.azurenative.search.inputs.PrivateEndpointConnectionPropertiesPrivateLinkServiceConnectionStateArgs.builder()
            .actionsRequired(actionsRequired?.applyValue({ args0 -> args0 }))
            .description(description?.applyValue({ args0 -> args0 }))
            .status(status?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) })).build()
}

/**
 * Builder for [PrivateEndpointConnectionPropertiesPrivateLinkServiceConnectionStateArgs].
 */
@PulumiTagMarker
public class PrivateEndpointConnectionPropertiesPrivateLinkServiceConnectionStateArgsBuilder
internal constructor() {
    private var actionsRequired: Output<String>? = null

    private var description: Output<String>? = null

    private var status: Output<PrivateLinkServiceConnectionStatus>? = null

    /**
     * @param value A description of any extra actions that may be required.
     */
    @JvmName("huavurdvttewewns")
    public suspend fun actionsRequired(`value`: Output<String>) {
        this.actionsRequired = value
    }

    /**
     * @param value The description for the private link service connection state.
     */
    @JvmName("ctcxklsmbywqpwmi")
    public suspend fun description(`value`: Output<String>) {
        this.description = value
    }

    /**
     * @param value Status of the the private link service connection. Can be Pending, Approved, Rejected, or Disconnected.
     */
    @JvmName("epncqhtcdihtfgkv")
    public suspend fun status(`value`: Output<PrivateLinkServiceConnectionStatus>) {
        this.status = value
    }

    /**
     * @param value A description of any extra actions that may be required.
     */
    @JvmName("nyffdnhwpampniig")
    public suspend fun actionsRequired(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.actionsRequired = mapped
    }

    /**
     * @param value The description for the private link service connection state.
     */
    @JvmName("fxypqqmxkoulapkk")
    public suspend fun description(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.description = mapped
    }

    /**
     * @param value Status of the the private link service connection. Can be Pending, Approved, Rejected, or Disconnected.
     */
    @JvmName("uiiybluygndagwmn")
    public suspend fun status(`value`: PrivateLinkServiceConnectionStatus?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.status = mapped
    }

    internal fun build(): PrivateEndpointConnectionPropertiesPrivateLinkServiceConnectionStateArgs =
        PrivateEndpointConnectionPropertiesPrivateLinkServiceConnectionStateArgs(
            actionsRequired = actionsRequired,
            description = description,
            status = status,
        )
}
